/*
 * OPALE is a scientific library under LGPL. Its main goal is to
 * develop mathematical tools for any scientist.
 *
 * Copyright (C) 2002 Opale Group
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * You can visit the web site http://opale.tuxfamily.org to obtain more
 * informations about this program and/or to contact the authors by mail
 * developers@opale.tuxfamily.org.
 */

package otests.ode.ee1d;

import opale.tools.*;
import opale.mathtools.*;
import opale.ode.*;
import opale.ode.scheme.*;


public class ee1d  implements OTest
	{
	
	public void run(String path)
	{
	
	Problem pb = new Problem();
	ExplicitEuler ts = new ExplicitEuler();
	pb.setEqn(
		new Equation()
			{
			DVect y = new DVect(1);
			public int dim() { return 1; }
			public DVect derivs(double t, DVect x)
				{
				y.set(0,1);
				return y;
				}
			}
		);

	pb.setTS(ts);
	pb.solve();
	
	try
	{
	WFile wf = new WFile(path+"resu1.txt");
	pb.writeSol(wf);
	wf.writeln("");
	wf.close();
	}
	catch(java.io.IOException e)
	{}	


	// resolution de y'=y, y(0)=1 (sol exacte exp(t))
	pb.setEqn(
		new Equation()
			{
			public int dim() { return 1; }
			public DVect derivs(double t, DVect x)
				{
				return x;
				}
			}
		);
	
	DVect cd = new DVect(1);
	cd.set(0,1);
	pb.setInit(cd);
	pb.solve();
	
	try
	{
	WFile wf = new WFile(path+"resu2.txt");
	pb.writeSol(wf);
	wf.writeln("");
	wf.close();
	}
	catch(java.io.IOException e)
	{}	
	
	// resolution de y'=-2*ty, y(0)=1 (sol exacte 1/(1+t))
	pb.setEqn(
		new Equation()
			{
			DVect y = new DVect(1);
			public int dim() { return 1; }
			public DVect derivs(double t, DVect x)
				{
				y.set(0,-2*t*x.get(0)*x.get(0));
				return y;
				}
			}
		);
	
	cd.set(0,0.5);
	ts.set(-1,1);
	pb.setInit(cd);
	pb.solve();
	
	try
	{
	WFile wf = new WFile(path+"resu3.txt");
	pb.writeSol(wf);
	wf.writeln("");
	wf.close();
	}
	catch(java.io.IOException e)
	{}	
	
	// resolution de y'=2*ty, y(0)=1 (sol exacte 1/(1-t))
	pb.setEqn(
		new Equation()
			{
			DVect y = new DVect(1);
			public int dim() { return 1; }
			public DVect derivs(double t, DVect x)
				{
				y.set(0,2*t*x.get(0)*x.get(0));
				return y;
				}
			}
		);
	
	cd.set(0,1);
	ts.setNstep(5000);
	ts.set(0,0.9);
	pb.setInit(cd);
	pb.solve();
	
	try
	{
	WFile wf = new WFile(path+"resu4.txt");
	pb.writeSol(wf);
	wf.writeln("");
	wf.close();
	}
	catch(java.io.IOException e)
	{}	
	
	// resolution de y'=-y, y(0)=1 (sol exacte 1/(1+t))
	pb.setEqn(
		new Equation()
			{
			DVect y = new DVect(1);
			public int dim() { return 1; }
			public DVect derivs(double t, DVect x)
				{
				y.set(0,-x.get(0)*x.get(0));
				return y;
				}
			}
		);
	
	cd.set(0,1);
	ts.setNstep(100);
	ts.set(0,10);
	pb.setInit(cd);
	pb.solve();
	
	try
	{
	WFile wf = new WFile(path+"resu5.txt");
	pb.writeSol(wf);
	wf.writeln("");
	wf.close();
	}
	catch(java.io.IOException e)
	{}	
	
	}

	public void stop() {};

}
